@@ -13,7 +13,7 @@ from tqdm import tqdm
 ASSET_DIR_IN_PROG = Path(__file__).parent.absolute().joinpath("assets")
 CLOCK_DIR_IN_PROG = ASSET_DIR_IN_PROG / "clock"
 SOUND_DIR_IN_PROG = ASSET_DIR_IN_PROG / "sound"
-ASSET_DIR_IN_SYS = Path(Path.home(), ".exclock")
+ASSET_DIR_IN_SYS = Path(Path.home(), ".config", "exclock")
 CLOCK_DIR_IN_SYS = Path(os.getenv('EXCLOCK_CLOCK_DIR', str(ASSET_DIR_IN_SYS / "clock"))).absolute()
 SOUND_DIR_IN_SYS = Path(os.getenv('EXCLOCK_SOUND_DIR', str(ASSET_DIR_IN_SYS / "sound"))).absolute()
 
